# Django Contacts
#### Brandon R. Stoner <monokrome@monokro.me>

## What is this?

A simple, fairly flexible framework for working with user contacts in
django. Includes support for groups, locations, and arbitrary custom
data types.

## What's next?
- Views for the data.
- Geodata when an applicable database is used

